==> frysk-0.2.1.tar.bz2: frysk-0.2.1/frysk-core/frysk/testbed/TestIsa.java <==
// This file is part of the program FRYSK.
//
// Copyright 2008, Red Hat Inc.
//
// FRYSK is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// FRYSK is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with FRYSK; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
// 
// In addition, as a special exception, Red Hat, Inc. gives You the
// additional right to link the code of FRYSK with code not covered
// under the GNU General Public License ("Non-GPL Code") and to
// distribute linked combinations including the two, subject to the
// limitations in this paragraph. Non-GPL Code permitted under this
// exception must only link to the code of FRYSK through those well
// defined interfaces identified in the file named EXCEPTION found in
// the source code files (the "Approved Interfaces"). The files of
// Non-GPL Code may instantiate templates or use macros or inline
// functions from the Approved Interfaces without causing the
// resulting work to be covered by the GNU General Public
// License. Only Red Hat, Inc. may make changes or additions to the
// list of Approved Interfaces. You must obey the GNU General Public
// License in all respects for all of the FRYSK code and other code
// used in conjunction with FRYSK except the Non-GPL Code covered by
// this exception. If you modify this file, you may extend this
// exception to your version of the file, but you are not obligated to
// do so. If you do not wish to provide this exception without
// modification, you must delete this exception statement from your
// version and license this file solely under the GPL without
// exception.

package frysk.testbed;

import java.io.File;
import frysk.isa.ISA;
import frysk.config.Config;

/**
 * Test IsaTestbed.
 */

public class TestIsa extends TestLib {

    public void testIsaValid() {
	assertNotNull("isa", IsaTestbed.getISA());
    }
    public void testIsa32Valid() {
	if (missing32or64())
	    return;
	assertNotNull("isa32", IsaTestbed.getISA32());
    }
    public void testIsa64Valid() {
	if (missing32or64())
	    return;
	assertNotNull("isa32", IsaTestbed.getISA32());
    }

    private void checkIsaMatchesBlockedProcess(ISA isa, File exe) {
	assertSame("running isa",
		   new DaemonBlockedAtEntry(exe).getMainTask().getISA(),
		   isa);
    }
    public void testIsaMatchesBlockedProcess() {
	checkIsaMatchesBlockedProcess(IsaTestbed.getISA(),
				      Config.getPkgLibFile("funit-slave"));
    }
    public void testIsa32MatchesBlockedProcess() {
	if (missing32or64())
	    return;
	checkIsaMatchesBlockedProcess(IsaTestbed.getISA32(),
				      Config.getPkgLib32File("funit-slave"));
    }
    public void testIsa64MatchesBlockedProcess() {
	if (missing32or64())
	    return;
	checkIsaMatchesBlockedProcess(IsaTestbed.getISA64(),
				      Config.getPkgLib64File("funit-slave"));
    }
}

==> frysk-0.3.tar.bz2: frysk-0.3/frysk-core/frysk/testbed/TestIsa.java <==
// This file is part of the program FRYSK.
//
// Copyright 2008, Red Hat Inc.
//
// FRYSK is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// FRYSK is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with FRYSK; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
// 
// In addition, as a special exception, Red Hat, Inc. gives You the
// additional right to link the code of FRYSK with code not covered
// under the GNU General Public License ("Non-GPL Code") and to
// distribute linked combinations including the two, subject to the
// limitations in this paragraph. Non-GPL Code permitted under this
// exception must only link to the code of FRYSK through those well
// defined interfaces identified in the file named EXCEPTION found in
// the source code files (the "Approved Interfaces"). The files of
// Non-GPL Code may instantiate templates or use macros or inline
// functions from the Approved Interfaces without causing the
// resulting work to be covered by the GNU General Public
// License. Only Red Hat, Inc. may make changes or additions to the
// list of Approved Interfaces. You must obey the GNU General Public
// License in all respects for all of the FRYSK code and other code
// used in conjunction with FRYSK except the Non-GPL Code covered by
// this exception. If you modify this file, you may extend this
// exception to your version of the file, but you are not obligated to
// do so. If you do not wish to provide this exception without
// modification, you must delete this exception statement from your
// version and license this file solely under the GPL without
// exception.

package frysk.testbed;

import java.io.File;
import frysk.isa.ISA;
import frysk.config.Prefix;

/**
 * Test IsaTestbed.
 */

public class TestIsa extends TestLib {

    public void testIsaValid() {
	assertNotNull("isa", IsaTestbed.getISA());
    }
    public void testIsa32Valid() {
	if (missing32or64())
	    return;
	assertNotNull("isa32", IsaTestbed.getISA32());
    }
    public void testIsa64Valid() {
	if (missing32or64())
	    return;
	assertNotNull("isa32", IsaTestbed.getISA32());
    }

    private void checkIsaMatchesBlockedProcess(ISA isa, File exe) {
	assertSame("running isa",
		   new DaemonBlockedAtEntry(exe).getMainTask().getISA(),
		   isa);
    }
    public void testIsaMatchesBlockedProcess() {
	checkIsaMatchesBlockedProcess(IsaTestbed.getISA(),
				      Prefix.pkgLibFile("funit-slave"));
    }
    public void testIsa32MatchesBlockedProcess() {
	if (missing32or64())
	    return;
	checkIsaMatchesBlockedProcess(IsaTestbed.getISA32(),
				      Prefix.pkgLib32File("funit-slave"));
    }
    public void testIsa64MatchesBlockedProcess() {
	if (missing32or64())
	    return;
	checkIsaMatchesBlockedProcess(IsaTestbed.getISA64(),
				      Prefix.pkgLib64File("funit-slave"));
    }
}
